//*-*-Skylec Shader-*-*

#version 120
#include "/include/lib.h"
uniform sampler2D lightmap;
uniform sampler2D texture;
uniform int isEyeInWater;
uniform float far;
uniform float rainStrength;
uniform vec3 fogColor;
uniform vec3 skyColor;

varying float isPlant;
varying float isSnow;
varying float isOre;
varying vec2 lmcoord;
varying vec2 texcoord;
varying vec3 glnormal;
varying vec3 sunPos;
varying vec3 nPos;
varying vec3 cPos;
varying vec3 wPos;
varying vec4 glcolor;

void main(){
vec4 diffuse=texture2D(texture,texcoord)*glcolor;
#ifdef ORIGINAL_WATER
float lmy=1.;
if(isEyeInWater!=1)lmy=lmcoord.y;
diffuse*=texture2D(lightmap,vec2(lmcoord.x,lmy));
#else
diffuse*=texture2D(lightmap,lmcoord);
#endif

float indoor=smoothstep(.8,.9,lmcoord.y);
float cave=smoothstep(1.,.5,lmcoord.y);
float day=saturate(skyColor.r*2.);
float sunset=saturate((fogColor.r-.1)-fogColor.b);

#ifdef ORIGINAL_TONEMAP
diffuse.rgb=mix(mix(diffuse.rgb,toneMap(diffuse.rgb,nightColor),1.-cave),diffuse.rgb,day);
#endif

#ifdef DUSK
diffuse.rgb=mix(diffuse.rgb,mix(diffuse.rgb,mix(toneMap(diffuse.rgb,duskColor),diffuse.rgb,rainStrength),indoor),sunset);
#endif

#ifdef SHADOWS
if(isEyeInWater==0){
float shadowDepth=mix(mix(1.,.73,day),1.,lmcoord.x*1.2);
float mainShadow=smoothstep(.95,.96,lmcoord.y);
float sideShadow=smoothstep(.64,.68,glcolor.g);
diffuse.rgb*=mix(shadowDepth,1.,mainShadow);
if(dot(glnormal,sunPos)<=.5)if(glcolor.r==glcolor.g&&glcolor.g==glcolor.b)diffuse.rgb*=mix(mix(1.,shadowDepth,mainShadow),1.,sideShadow);
if(isPlant>=.5)diffuse.rgb*=mix(mix(1.,shadowDepth,mainShadow),1.,saturate(dot(glnormal,sunPos)));
}
#endif

#ifdef GLOWING_ORE
vec3 t=texture2D(texture,texcoord).rgb;
if(isOre>=.5)diffuse.rgb+=mix(vec3(0.),diffuse.rgb+t.rgb,vec3(smoothstep(0.,.1,length(cross(vec3(length(t)),t*.2)))))*cave*(1.-lmcoord.x);
#endif

#ifdef LIGHT_COLOR
diffuse.rgb+=mix(lightColor*max(lmcoord.x-.5,0.),vec3(.0),(indoor*.5+day*1.5)*.5);
diffuse.rgb+=mix(vec3(0.),vec3(.0,.0,1.8)*max(lmcoord.x-.67,0.),saturate(float(isEyeInWater)));
#endif

#ifdef ORIGINAL_WATER
if(isEyeInWater==1){
vec3 p=cPos;p.xz*=vec2(.75,.3);
float wave=snoise(p.xz+frameTimeCounter*.3)+snoise(vec2(p.x+frameTimeCounter*.4,(p.z+frameTimeCounter*1.5)*.5));
diffuse.rgb+=mix(vec3(0.),vec3(.1),saturate(.8-abs(wave)));}
#endif

#ifdef FOG
diffuse.rgb=mix(diffuse.rgb,(pow(skyColor,vec3(3.4))+fogColor)/vec3(2.),smoothstep(0.,far,length(wPos.zx)));
#endif

gl_FragData[0]=diffuse;
}