//*-*-Skylec Shader-*-*

#version 120
#include "/include/lib.h"
uniform sampler2D lightmap;
uniform sampler2D texture;
uniform int isEyeInWater;
uniform float far;
uniform float rainStrength;
uniform vec3 fogColor;
uniform vec3 skyColor;

varying float isWater;
varying vec2 lmcoord;
varying vec2 texcoord;
varying vec3 glnormal;
varying vec3 sunPos;
varying vec3 cPos;
varying vec3 wPos;
varying vec4 glcolor;

void main(){
vec4 diffuse=texture2D(texture,texcoord)*glcolor;
#ifdef ORIGINAL_WATER
float lmy=1.;
if(isEyeInWater!=1)lmy=lmcoord.y;
diffuse*=texture2D(lightmap,vec2(lmcoord.x,lmy));
#else
diffuse*=texture2D(lightmap,lmcoord);
#endif
float indoor=smoothstep(.8,.9,lmcoord.y);
float cave=smoothstep(1.,.5,lmcoord.y);
float day=saturate(skyColor.r*2.);
float sunset=saturate((fogColor.r-.1)-fogColor.b);

#ifdef ORIGINAL_TONEMAP
diffuse.rgb=mix(mix(diffuse.rgb,toneMap(diffuse.rgb,nightColor),indoor),diffuse.rgb,day);
#endif

#ifdef DUSK
diffuse.rgb=mix(diffuse.rgb,mix(diffuse.rgb,mix(toneMap(diffuse.rgb,duskColor),diffuse.rgb,rainStrength),indoor),sunset);
#endif

#ifdef ORIGINAL_WATER
if(isWater>=.5&&isEyeInWater!=1){
vec3 p=cPos;p.xz*=vec2(.75,.3);
vec3 nWPos=normalize(wPos);
float wave=snoise(p.xz+frameTimeCounter*.3)+snoise(vec2(p.x+frameTimeCounter*.4,(p.z+frameTimeCounter*1.5)*.5));
float cHeight=.18;
float cloudRef=saturate(snoise((wPos.xz+wave*2.*wPos.xz/max(abs(length(wPos.xz)),.5))*cHeight));
float moonRef=saturate((1.-length(nWPos.z*3.)));
vec3 cc=mix(mix(mix(vec3(.53,.53,.76),vec3(1.),day),vec3(.16),rainStrength),vec3(1.4,.8,.8),sunset);
float wLen=saturate(length(nWPos.xz*.7/nWPos.y));
#ifdef ORIGINAL_TONEMAP
diffuse.rgb*=mix(vec3(.4),vec3(.6,1.,.9),day);
#endif
diffuse.rgb*=mix(vec3(.93),vec3(1.),wave);
diffuse.rgb=mix(diffuse.rgb,cc,(cloudRef*.3*wLen+moonRef*mix(mix(.4,.3,day),.6,sunset)*pow(abs(wave),2.)*wLen)*lmcoord.y);
}
#endif

#ifdef ORIGINAL_TONEMAP
diffuse.rgb=mix(mix(diffuse.rgb,toneMap(diffuse.rgb,nightColor),1.-cave),diffuse.rgb,day);
#endif

#ifdef ORIGINAL_WATER
if(isEyeInWater==1){
vec3 p=cPos;p.xz*=vec2(.75,.3);
float wave=snoise(p.xz+frameTimeCounter*.3)+snoise(vec2(p.x+frameTimeCounter*.4,(p.z+frameTimeCounter*1.5)*.5));
diffuse.rgb+=mix(vec3(0.),vec3(.1),saturate(.8-abs(wave)));}
#endif


#ifdef FOG
diffuse.rgb=mix(diffuse.rgb,(skyColor+fogColor)/vec3(2.),smoothstep(0.,far,length(wPos.zx)));
#endif
gl_FragData[0]=diffuse;
}